sqlobject.tests.test_unicode module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_unicode module

class `sqlobject.tests.test_unicode.` `SOTestUnicode`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `byCol`(val, connection=None)
  classmethod `bySo_count`(val, connection=None)
  property `col`
  `j` = so_test_unicode
  `q` = so_test_unicode
  property `so_count`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_unicode.SOTestUnicode`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_unicode'

`sqlobject.tests.test_unicode.` `setup`()

`sqlobject.tests.test_unicode.` `test_create`()

`sqlobject.tests.test_unicode.` `test_select`()